@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Utility functions
 #
-# Copyright (C) 2001-2016 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -32,17 +32,30 @@ to a local file.
 """
 from __future__ import print_function, unicode_literals
 from __future__ import division
+from abc import ABCMeta, abstractmethod
+from six import add_metaclass
 
-import sys
+import functools
+import textwrap
 import io
 import os
-import textwrap
 import re
+import sys
 import zipfile
 import codecs
 
 from gzip import GzipFile, READ as GZ_READ, WRITE as GZ_WRITE
 
+try: # Python 3.
+    textwrap_indent = functools.partial(textwrap.indent, prefix='  ')
+except AttributeError: # Python 2; indent() not available for Python2.
+    textwrap_fill = functools.partial(textwrap.fill,
+                                        initial_indent='  ',
+                                        subsequent_indent='  ',
+                                        replace_whitespace=False)
+    def textwrap_indent(text):
+        return '\n'.join(textwrap_fill(line) for line in text.splitlines())
+
 try:
     from zlib import Z_SYNC_FLUSH as FLUSH
 except ImportError:
@@ -53,12 +66,12 @@ try:
 except ImportError:
     import pickle
 
+from six import string_types, text_type
+from six.moves.urllib.request import urlopen, url2pathname
+
 # this import should be more specific:
 import nltk
-
-from nltk.compat import py3_data, add_py3_data
-from nltk.compat import text_type, string_types, BytesIO, urlopen, url2pathname
-
+from nltk.compat import py3_data, add_py3_data, BytesIO
 
 ######################################################################
 # Search Path
@@ -82,6 +95,7 @@ if sys.platform.startswith('win'):
     path += [
         str(r'C:\nltk_data'), str(r'D:\nltk_data'), str(r'E:\nltk_data'),
         os.path.join(sys.prefix, str('nltk_data')),
+        os.path.join(sys.prefix, str('share'), str('nltk_data')),
         os.path.join(sys.prefix, str('lib'), str('nltk_data')),
         os.path.join(
             os.environ.get(str('APPDATA'), str('C:\\')), str('nltk_data'))
@@ -92,7 +106,10 @@ else:
         str('/usr/share/nltk_data'),
         str('/usr/local/share/nltk_data'),
         str('/usr/lib/nltk_data'),
-        str('/usr/local/lib/nltk_data')
+        str('/usr/local/lib/nltk_data'),
+        os.path.join(sys.prefix, str('nltk_data')),
+        os.path.join(sys.prefix, str('share'), str('nltk_data')),
+        os.path.join(sys.prefix, str('lib'), str('nltk_data'))
     ]
 
 
@@ -100,8 +117,8 @@ else:
 # Util Functions
 ######################################################################
 
-def gzip_open_unicode(filename, mode="rb", compresslevel=9,
-                      encoding='utf-8', fileobj=None, errors=None, newline=None):
+def gzip_open_unicode(filename, mode="rb", compresslevel=9, encoding='utf-8',
+                      fileobj=None, errors=None, newline=None):
     if fileobj is None:
         fileobj = GzipFile(filename, mode, compresslevel, fileobj)
     return io.TextIOWrapper(fileobj, encoding, errors, newline)
@@ -241,6 +258,7 @@ def normalize_resource_name(resource_name, allow_relative=True, relative_path=No
 # Path Pointers
 ######################################################################
 
+@add_metaclass(ABCMeta)
 class PathPointer(object):
     """
     An abstract base class for 'path pointers,' used by NLTK's data
@@ -251,6 +269,7 @@ class PathPointer(object):
     by reading that zipfile.
     """
 
+    @abstractmethod
     def open(self, encoding=None):
         """
         Return a seekable read-only stream that can be used to read
@@ -259,8 +278,8 @@ class PathPointer(object):
         :raise IOError: If the path specified by this pointer does
             not contain a readable file.
         """
-        raise NotImplementedError('abstract base class')
 
+    @abstractmethod
     def file_size(self):
         """
         Return the size of the file pointed to by this path pointer,
@@ -269,8 +288,8 @@ class PathPointer(object):
         :raise IOError: If the path specified by this pointer does
             not contain a readable file.
         """
-        raise NotImplementedError('abstract base class')
 
+    @abstractmethod
     def join(self, fileid):
         """
         Return a new path pointer formed by starting at the path
@@ -279,7 +298,6 @@ class PathPointer(object):
         should be separated by forward slashes, regardless of
         the underlying file system's path seperator character.
         """
-        raise NotImplementedError('abstract base class')
 
 
 class FileSystemPathPointer(PathPointer, text_type):
@@ -369,11 +387,6 @@ class BufferedGzipFile(GzipFile):
         """
         GzipFile.__init__(self, filename, mode, compresslevel, fileobj)
         self._size = kwargs.get('size', self.SIZE)
-        # Note: In > Python3.5, GzipFile is already using a 
-        # buffered reader in the backend which has a variable self._buffer
-        # See https://github.com/nltk/nltk/issues/1308
-        if sys.version.startswith('3.5'):
-            sys.stderr.write("Use the native Python gzip.GzipFile instead.")
         self._nltk_buffer = BytesIO()
         # cStringIO does not support len.
         self._len = 0
@@ -445,7 +458,13 @@ class GzipFileSystemPathPointer(FileSystemPathPointer):
     """
 
     def open(self, encoding=None):
-        stream = BufferedGzipFile(self._path, 'rb')
+        # Note: In >= Python3.5, GzipFile is already using a
+        # buffered reader in the backend which has a variable self._buffer
+        # See https://github.com/nltk/nltk/issues/1308
+        if sys.version.startswith('2.7') or sys.version.startswith('3.4'):
+            stream = BufferedGzipFile(self._path, 'rb')
+        else:
+            stream = GzipFile(self._path, 'rb')
         if encoding:
             stream = SeekableUnicodeStreamReader(stream, encoding)
         return stream
@@ -472,7 +491,7 @@ class ZipFilePathPointer(PathPointer):
         entry = normalize_resource_name(entry, True, '/').lstrip('/')
 
         # Check that the entry exists:
-        if entry:
+        if entry != '.':
             try:
                 zipfile.getinfo(entry)
             except Exception:
@@ -510,7 +529,13 @@ class ZipFilePathPointer(PathPointer):
         data = self._zipfile.read(self._entry)
         stream = BytesIO(data)
         if self._entry.endswith('.gz'):
-            stream = BufferedGzipFile(self._entry, fileobj=stream)
+            # Note: In >= Python3.5, GzipFile is already using a
+            # buffered reader in the backend which has a variable self._buffer
+            # See https://github.com/nltk/nltk/issues/1308
+            if sys.version.startswith('2.7') or sys.version.startswith('3.4'):
+                stream = BufferedGzipFile(self._entry, fileobj=stream)
+            else:
+                stream = GzipFile(self._entry, fileobj=stream)
         elif encoding is not None:
             stream = SeekableUnicodeStreamReader(stream, encoding)
         return stream
@@ -527,7 +552,9 @@ class ZipFilePathPointer(PathPointer):
             self._zipfile.filename, self._entry)
 
     def __str__(self):
-        return os.path.normpath(os.path.join(self._zipfile.filename, self._entry))
+        return os.path.normpath(os.path.join(self._zipfile.filename,
+                                             self._entry))
+
 
 ######################################################################
 # Access Functions
@@ -629,15 +656,22 @@ def find(resource_name, paths=None):
             except LookupError:
                 pass
 
+    # Identify the package (i.e. the .zip file) to download.
+    resource_zipname = resource_name.split('/')[1]
+    if resource_zipname.endswith('.zip'):
+        resource_zipname = resource_zipname.rpartition('.')[0]
     # Display a friendly error message if the resource wasn't found:
-    msg = textwrap.fill(
-        'Resource %r not found.  Please use the NLTK Downloader to '
-        'obtain the resource:  >>> nltk.download()' %
-        (resource_name,), initial_indent='  ', subsequent_indent='  ',
-        width=66)
+    msg = str("Resource \33[93m{resource}\033[0m not found.\n"
+              "Please use the NLTK Downloader to obtain the resource:\n\n"
+              "\33[31m" # To display red text in terminal.
+              ">>> import nltk\n"
+              ">>> nltk.download(\'{resource}\')\n"
+              "\033[0m").format(resource=resource_zipname)
+    msg = textwrap_indent(msg)
+
     msg += '\n  Searched in:' + ''.join('\n    - %r' % d for d in paths)
     sep = '*' * 70
-    resource_not_found = '\n%s\n%s\n%s' % (sep, msg, sep)
+    resource_not_found = '\n%s\n%s\n%s\n' % (sep, msg, sep)
     raise LookupError(resource_not_found)
 
 
@@ -678,6 +712,7 @@ def retrieve(resource_url, filename=None, verbose=True):
 
     infile.close()
 
+
 #: A dictionary describing the formats that are supported by NLTK's
 #: load() method.  Keys are format names, and values are format
 #: descriptions.
@@ -979,7 +1014,7 @@ class OpenOnDemandZipFile(zipfile.ZipFile):
         zipfile.ZipFile.__init__(self, filename)
         assert self.filename == filename
         self.close()
-        # After closing a ZipFile object, the _fileRefCnt needs to be cleared 
+        # After closing a ZipFile object, the _fileRefCnt needs to be cleared
         # for Python2and3 compatible code.
         self._fileRefCnt = 0
 
@@ -1444,6 +1479,7 @@ class SeekableUnicodeStreamReader(object):
 
         return None
 
+
 __all__ = ['path', 'PathPointer', 'FileSystemPathPointer', 'BufferedGzipFile',
            'GzipFileSystemPathPointer', 'GzipFileSystemPathPointer',
            'find', 'retrieve', 'FORMATS', 'AUTO_FORMATS', 'load',
